local const = require("const")
local json = require("json")
local utils = require("utils")
local utils_device = require("utils_device")
local resty_string = require("resty.string")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DeviceManage")


local function apply_new_device(driver_name, product_key)
    local params = {}
    params["params"] = {}
    params["params"]["driverName"] = driver_name
    params["params"]["productKey"] = product_key
    params["params"]["count"] = 1
    local ok, msg_raw, err = utils.dbus_call_edge(
                                const.dimu.wkn,
                                const.dimu.obj,
                                const.dimu.inf,
                                "allocateDeviceNameAndAuthorizeAsLocalId",
                                json.encode(params))
    if (ok and msg_raw) then
        local ok, msg = pcall(json.decode, msg_raw[1])
        if (0 == msg["code"]) then
            return msg["params"][1] -- get device name
        end
    end

    utils.log_error("call dimu.allocateDeviceNameAndAuthorizeAsLocalId failed" .. err)
    utils.error_exit(500, "apply new device failed")
end

if ("POST" == request_method) then
    ngx.req.read_body()
    local args_json = ngx.req.get_body_data()
    if (nil == args_json) then
        utils.error_exit(400)
    end
    local args = json.decode(args_json)
    if (nil == args) then
        utils.error_exit(400)
    end

    local driver_name = args["DriverName"]
    local pk = args["ProductKey"]
    local dev_config = args["DeviceConfig"]

    if (not (driver_name and pk and dev_config and "table" == type(dev_config))) then
        utils.error_exit(400)
    end

    -- apply a new device from dimu
    local dn = apply_new_device(driver_name, pk)

    -- store new device config
    utils_device.set_device_config(driver_name, pk, dn, dev_config)
    local res = {}
    res["DriverName"] = driver_name
    res["ProductKey"] = pk
    res["DeviceName"] = dn
    utils.error_exit(200, json.encode(res))
elseif ("DELETE" == request_method) then

end

utils.error_exit(400, "Invalid request method")
