# -*- coding: utf-8 -*-
import sqlite3
import time, os, json
import lecoresdk

lesdk = lecoresdk.IoTData()

# User-defined parameters
db_file_path = "/linkedge/run/fc-runtime-data/"
db_file_name = "device-data-sqlite3.db"

if os.path.exists(db_file_path) == False:
    os.makedirs(db_file_path)

connect = sqlite3.connect(db_file_path + db_file_name)
cursor = connect.cursor()


def handler(event, parameters):
    print("-- Receive new event: ", event)
    try:
        edict = json.loads(event)
        topic = edict['topic']
        tlist = topic.split('/')
        if tlist[1] == 'sys':
            productKey = tlist[2]
            deviceName = tlist[3]
            tableName = productKey + '_' + deviceName
            print("-- Table Name : " + tableName)
        else:
            print("-- [Warn] Event topic should start with /sys/. Ignore!")
            return 'OK'

        payload = json.loads(edict['payload'])
        for key, value in payload.items():
            print("-- Get average value of key:" + key + " in 5 minutes:")
            cursor.execute(
                "SELECT avg(VALUE) FROM {} WHERE KEY = ? AND TIMESTAMP >= datetime('now','-5 minutes','localtime')".format(
                    tableName), [key])
            avg_value = cursor.fetchone()[0]
            print("-- Average value of {}={}".format(key, avg_value))
            if avg_value > 240:
                print("-- Turn off the Light.")
                set_params = {"productKey": "a1ZJTVsqj2y", "deviceName": "LightDev", "payload": {"LightSwitch": 0}}
                res = lesdk.setThingProperties(set_params)

        # [Optional- DB query Sample] Show the last 3 entries
        print("-- Show table " + tableName + " last 3 entries:")
        cursor.execute("SELECT rowid,* FROM %s ORDER BY TIMESTAMP DESC LIMIT %d" % (tableName, 3))
        for row in cursor.fetchall():
            print(row)
    except Exception as e:
        print("-- [Warn] Event parse failed. Ignore! ", e)

    return 'OK'
